-- Import
local _, addonData = ...;
local events = {};

-- Important locals
local className, classFileName = UnitClass("player");
local _,_,_,classColor = GetClassColor(classFileName);

-- Globals
DLU.player = {
	level = UnitLevel("player"),
	name = UnitName("player"),
	class = className,
	classWithColor = format("|c%s%s|r", classColor, className);
}

function DLU.CheckClassMountStatus()
	
	local classMountTable = {
		["DEATHKNIGHT"] = 866,
		["DEMONHUNTER"] = 868,
		["DRUID"] = 231437,
		["HUNTER"] = 865,
		["MAGE"] = 860,
		["MONK"] = 864,
		["PALADIN"] = 885,
		["PRIEST"] = 861,
		["ROGUE"] = 884,
		["SHAMAN"] = 888,
		["WARLOCK"] = 898,
		["WARRIOR"] = 867
	};
	
	--IsQuestFlaggedCompleted(questId)
	
	local hasClassMount = false;
	if (classFileName == "DRUID") then
		hasClassMount = IsSpellKnown(classMountTable[classFileName]);
	else
		local _, _, _, _, _, _, _, _, _, _, isCollected = C_MountJournal.GetMountInfoByID(classMountTable[classFileName]);
		hasClassMount = isCollected;
	end
	
	if (hasClassMount) then
		DLU.createMessage("You have the mount, congratz!", "");
	else
		local achievementTable = {
			["part1"] = 10994,
			["part2"] = 11546
		};
		
		local _, achievementName, _, _, _, _, _, _, _, _, _, _, wasEarnedByMe = GetAchievementInfo(achievementTable["part1"]);
		if (wasEarnedByMe) then
			_, achievementName, _, _, _, _, _, _, _, _, _, _, wasEarnedByMe = GetAchievementInfo(achievementTable["part2"]);
			if (not wasEarnedByMe) then
				DLU.createMessage(format("You need to complete %s (achievement).", achievementName), "error");
				AddTrackedAchievement(achievementTable["part2"]);
			end
		else 
			DLU.createMessage(format("You need to complete %s (achievement).", achievementName), "error");
			AddTrackedAchievement(achievementTable["part1"]);
		end
	end
end

-- Frames
local playerFrame = CreateFrame("Frame", "DLUPlayerFrame");

-- Local functions
local function playerLevelUp(self, event, ...)
	local newLevel = UnitLevel("player") + 1;
	
	DLU.player.level = newLevel;
	
	if (DLU.aprilsFool) then
		PlaySound(7641, "Master");
	end
end

-- Events
function events:PLAYER_LEVEL_UP(self, event, ...)
	playerLevelUp(self, event, ...);
end
function events:MERCHANT_SHOW()
	if (CanMerchantRepair() and DLUCharacterSettings.autoRepair.value == true) then
		local cost, canRepair = GetRepairAllCost();
		
		if (canRepair) then
			if (cost <= GetMoney()) then
				local guildGoldLimit = GetGuildBankWithdrawGoldLimit();
				if (guildGoldLimit > 0) then
					guildGoldLimit = guildGoldLimit * 10000;
				end
				
				local repairText = "";
				local repairCostString = GetCoinTextureString(cost);
				
				if (guildGoldLimit == -1 or guildGoldLimit >= cost) then
					RepairAllItems(1);
					repairText = format("Repaired gear costing %s using guild repair.", repairCostString);
				else
					RepairAllItems(nil);
					repairText = format("Repaired gear costing %s using character repair.", repairCostString);
				end
				
				DLU.createMessage(repairText, "");
			end
		end
	end
end

playerFrame:RegisterEvent("PLAYER_LOGIN");
playerFrame:SetScript("OnEvent", function()
	playerFrame:SetScript("OnEvent", function(self, event, ...)
		events[event](self, ...);
	end);
	for k, v in pairs(events) do
		playerFrame:RegisterEvent(k);
	end
end);