-- Import
local _, addonData = ...;

-- Functions
local function checkTemplateExists(name)
	for i = 1, #DLUCharacterSettings.Talents do
		if (name == DLUCharacterSettings.Talents[i].name) then
			return true;
		end
	end
	
	return false;
end

function DLU.CanChangeTemplate()
	return IsResting();
end

function DLU.SaveTemplate(name)
	local spec = GetSpecialization();
	local talentTemplate = {};
	talentTemplate.name = name;
	talentTemplate.talents = {};
	
	for i = 1, MAX_TALENT_TIERS do
		for j = 1, NUM_TALENT_COLUMNS do
			local id, name, _, selected = GetTalentInfo(i, j, 1);
			--print(id .. " name: " .. name .. " - Selected: " .. tostring(selected));
			
			if (selected) then
				table.insert(talentTemplate.talents, id);
			end
		end
	end
	
	if (DLUCharacterSettings.Talents == nil) then
		DLUCharacterSettings.Talents = {};
	end
	
	if (#talentTemplate.talents > 0) then
		if (checkTemplateExists(name)) then
			DLU.DeleteTemplate(name);
			table.insert(DLUCharacterSettings.Talents, talentTemplate);
			DLU.createMessage(format(addonData.L.TalentUpdated, name), "");
		else
			table.insert(DLUCharacterSettings.Talents, talentTemplate);
			DLU.createMessage(format(addonData.L.TalentSaved, name), "");
		end
	else
		DLU.createMessage(addonData.L.TalentSaveError, "error");
	end
end

function DLU.LoadTemplate(name)
	if (DLU.CanChangeTemplate()) then
		local talentTemplate = nil;
		
		for i = 1, #DLUCharacterSettings.Talents do
			if (name == DLUCharacterSettings.Talents[i].name) then
				talentTemplate = DLUCharacterSettings.Talents[i];
			end
		end
		
		if (talentTemplate ~= nil) then
			local spec = GetSpecialization();
			
			for i = 1, #talentTemplate.talents do
				local _, _, _, selected = GetTalentInfoByID(talentTemplate.talents[i], 1);
				if (selected == false) then
					LearnTalent(talentTemplate.talents[i]);
				end
			end
		end
		
		DLU.createMessage(format(addonData.L.TalentLoaded, name), "");
	else
		DLU.createMessage(addonData.L.TalentChangeError, "error");
	end
end

function DLU.DeleteTemplate(name, printMessage)
	local printMessage = printMessage or false;
	
	local talentTemplateId = nil;
	for i = 1, #DLUCharacterSettings.Talents do
		if (name == DLUCharacterSettings.Talents[i].name) then
			talentTemplateId = i;
		end
	end
	
	if (talentTemplateId ~= nil) then
		table.remove(DLUCharacterSettings.Talents, talentTemplateId);
		if (printMessage ~= false) then
			DLU.createMessage(format(addonData.L.TalentDeleted, name), "");
		end
	end
end